# eric7.Project.UicLoadUi6

Module to get the object name, class name or signatures of a Qt form (*.ui).

### Global Attributes

None

### Classes

None

### Functions

__mapType | Private function to map a type as reported by Qt's meta object to the correct Python type.
_printerr | Function to print the given string as error to sys.stdoerr with a guard string.
_printout | Function to print the given string as output to sys.stderr with a guard string.
className | Function to get the class name of a form.
objectName | Function to get the object name of a form.
signatures | Function to get the signatures of form elements.

## __mapType

__mapType(type_)

Private function to map a type as reported by Qt's meta object to the correct Python type.

type_ (QByteArray or bytes)
  type as reported by Qt

Return:
  mapped Python type

Return Type:
  str

Up

## _printerr

_printerr(dataString)

Function to print the given string as error to sys.stdoerr with a guard string.

dataString (str)
  string to be printed

Up

## _printout

_printout(dataString)

Function to print the given string as output to sys.stderr with a guard string.

dataString (str)
  string to be printed

Up

## className

className(formFile, projectPath)

Function to get the class name of a form.

formFile (str)
  file name of the form
projectPath (str)
  directory name of the project

Up

## objectName

objectName(formFile, projectPath)

Function to get the object name of a form.

formFile (str)
  file name of the form
projectPath (str)
  directory name of the project

Up

## signatures

signatures(formFile, projectPath)

Function to get the signatures of form elements.

formFile (str)
  file name of the form
projectPath (str)
  directory name of the project

Up